import request from '@/utils/request'

// 用户列表
export function getUserList(params: any) {
    return request.get({ url: '/user.user/lists', params }, { ignoreCancelToken: true })
}

// 产品列表列表
export function apiProductLists(params: any) {
    return request.get({ url: '/land.product/datas', params })
}

// 监测设备列表
export function apiDeviceLists(params: any) {
    return request.get({ url: '/device.device/lists', params })
}

// 添加监测设备
export function apiDeviceAdd(params: any) {
    return request.post({ url: '/device.device/add', params })
}

// 编辑监测设备
export function apiDeviceEdit(params: any) {
    return request.post({ url: '/device.device/edit', params })
}

// 删除监测设备
export function apiDeviceDelete(params: any) {
    return request.post({ url: '/device.device/delete', params })
}

// 监测设备详情
export function apiDeviceDetail(params: any) {
    return request.get({ url: '/device.device/detail', params })
}

// 设备监控数据
export function apiDeviceMonitorData(params: any) {
    return request.get({ url: '/device.device/monitorData', params })
}

// 设备编码和ICCID
export function apiDeviceIccid(params: any) {
    return request.get({ url: '/device.device/queryDeviceIccid', params })
}